Usage
=====

There are different possible uses.

Velocity gradient calculation
-----------------------------
Velocity gradient calculation is discussed in :ref:`doc_vgrad`



Offsets and Sky rotation calculation
------------------------------------
Offsets and
Sky rotation calculation is discussed in :ref:`doc_offset_rotation`


Velocity fields
---------------
Velocity fields is discussed in :ref:`doc_velocity_fields`

Streamline model
----------------
Streamline model is discussed in :ref:`doc_streamline`
